#
# RecurringEvent/utils.py
#

from AccessControl import ModuleSecurityInfo
from math import floor
security = ModuleSecurityInfo( 'Products.RecurringEvent' )

security.declarePublic('DT2m')
def DT2m(dt):
   """ returns number of day since epoch """
   return floor(float(dt.earliestTime().millis()) / float(86400000))    
   
security.declarePublic('daysAsKeywords')
def daysAsKeywords(start_dt, end_dt):
   days = []
   idt = start_dt
   while(idt.lessThanEqualTo(end_dt)):
      tdt = idt.earliestTime()
      days.append(DT2m(tdt))
      idt = (tdt + 1).earliestTime()
   return days  
   

security.declarePublic('weeksAsKeywords')
def weeksAsKeywords(start_dt, end_dt):
   weeks = []
   idt = start_dt
   while(idt.lessThanEqualTo(end_dt)):
      tdt = FDOW(idt).earliestTime()
      weeks.append(DT2m(tdt))
      idt = (tdt + 7).earliestTime()
   return weeks  

from Products.RecurringEvent.config import MONTH_LENGTH 
def numberOfDaysInMonth(dt):
       if dt.isLeapYear(): return MONTH_LENGTH['leapYear'][dt.month()]
       return MONTH_LENGTH['standardYear'][dt.month()]

security.declarePublic('monthsAsKeywords')
def monthsAsKeywords(start_dt, end_dt):
   months = []
   idt = start_dt
   while(idt.lessThanEqualTo(end_dt)):
      shift = numberOfDaysInMonth(idt)
      tdt = FDOM(idt).earliestTime()
      months.append(DT2m(tdt))
      idt = (tdt + shift).earliestTime()
   return months 
   
security.declarePublic('FDOM')
def FDOM(dt):
   fdom = dt - (dt.day() - 1)
   return fdom.earliestTime()
   
security.declarePublic('FDOW')
def FDOW(dt):
   fdow = dt - dt.dow()
   return fdow.earliestTime()
   
security.declarePublic('checkDH')
def checkDH(start, end, ev):
   sh = ev.start.hour()
   sm = ev.start.minute()
   
   return sh >= start.hour() and sh <= end.hour() and sm >= start.minute() and sm <= end.minute()
   
   
   
